@@ -40,6 +40,7 @@ class rtevalModulePrototype(threading.Thread):
                          "finished": threading.Event()}
         self._donotrun = False
         self._exclusive = False
+        self._latency_test = False
         self.__timestamps = {}
         self.__sleeptime = 2.0
 
@@ -67,6 +68,11 @@ class rtevalModulePrototype(threading.Thread):
         self._exclusive = True
 
 
+    def set_latency_test(self):
+        """ Sets the module as an exclusive latency measurer """
+        self._latency_test = True
+
+
     def set_donotrun(self):
         """ set a module's donotrun field to True """
         self._donotrun = True
@@ -118,8 +124,8 @@ class rtevalModulePrototype(threading.Thread):
 
     def WaitForCompletion(self, wtime=None):
         """ Blocks until the module has completed its workload """
-        if not self.shouldStart():
-            # If it hasn't been started yet, nothing to wait for
+        if self.hadRuntimeError() or not self.shouldStart():
+            # If it failed or hasn't been started yet, nothing to wait for
             return None
         return self.__events["finished"].wait(wtime)
 
@@ -169,7 +175,7 @@ class rtevalModulePrototype(threading.Thread):
         return self._donotrun is False
 
 
-    def run(self):
+    def __run(self):
         "Workload thread runner - takes care of keeping the workload running as long as needed"
         if self.shouldStop():
             return
@@ -209,6 +215,12 @@ class rtevalModulePrototype(threading.Thread):
 
         self._WorkloadCleanup()
 
+    def run(self):
+        try:
+            self.__run()
+        except Exception as e:
+            self._setRuntimeError()
+            raise e
 
     def MakeReport(self):
         """ required module method, needs to return an libxml2.xmlNode object
@@ -269,22 +281,28 @@ reference from the first import"""
             return mod
 
 
-    def ModuleInfo(self, modname, modroot=None):
-        """Imports a module and calls the modules' ModuleInfo() function and returns
-the information provided by the module"""
-
-        mod = self.LoadModule(modname, modroot)
-        return mod.ModuleInfo()
-
-
     def SetupModuleOptions(self, parser, config):
         """Sets up a separate argparse ArgumentGroup per module with its supported parameters"""
 
         grparser = parser.add_argument_group(f"Group Options for {self.__modtype} modules")
         grparser.add_argument(f'--{self.__modtype}-cpulist',
-                            dest=f'{self.__modtype}___cpulist', action='store', default="",
+                            dest=f'{self.__modtype}___cpulist', action='store',
+                            default="",
                             help=f'CPU list where {self.__modtype} modules will run',
-                            metavar='LIST')
+                            metavar='CPULIST')
+
+        # Set up options for measurement modules only
+        if self.__modtype == 'measurement':
+            grparser.add_argument(f'--{self.__modtype}-run-on-isolcpus',
+                                  dest = f'{self.__modtype}___run_on_isolcpus',
+                                  action = "store_true",
+                                  default = config.GetSection("measurement").setdefault("run-on-isolcpus", "false").lower() == "true",
+                                  help = "Include isolated CPUs in default cpulist")
+            grparser.add_argument(f'--{self.__modtype}-idle-set',
+                                  dest='measurement___idlestate',
+                                  metavar='IDLESTATE',
+                                  default=None,
+                                  help='Idle state depth to set on cpus running measurement modules')
 
         for (modname, mod) in list(self.__modsloaded.items()):
             opts = mod.ModuleParameters()
@@ -298,7 +316,7 @@ the information provided by the module"""
                 # Ignore if a section is not found
                 cfg = None
 
-            modgrparser = parser.add_argument_group(f"Options for the {shortmod} module")
+            grparser = parser.add_argument_group(f"Options for the {shortmod} module")
             for (o, s) in list(opts.items()):
                 descr = 'descr' in s and s['descr'] or ""
                 metavar = 'metavar' in s and s['metavar'] or None
@@ -313,7 +331,7 @@ the information provided by the module"""
                     default = 'default' in s and s['default'] or None
 
 
-                modgrparser.add_argument(f'--{shortmod}-{o}',
+                grparser.add_argument(f'--{shortmod}-{o}',
                                          dest=f"{shortmod}___{o}",
                                          action='store',
                                          help='%s%s' % (descr,
@@ -321,8 +339,6 @@ the information provided by the module"""
                                          default=default,
                                          metavar=metavar)
 
-            return grparser
-
 
     def InstantiateModule(self, modname, modcfg, modroot=None):
         """Imports a module and instantiates an object from the modules create() function.
@@ -341,36 +357,11 @@ returned when a ModuleContainer object is iterated over"""
         self.__modobjects[modname] = modobj
 
 
-    def ExportModule(self, modname, modroot=None):
-        "Export module info, used to transfer an imported module to another ModuleContainer"
-        if modroot is None:
-            modroot = self.__modules_root
-
-        mod = f"{modroot}.{modname}"
-        return (mod, self.__modsloaded[mod])
-
-
-    def ImportModule(self, module):
-        "Imports an exported module from another ModuleContainer"
-        (modname, moduleimp) = module
-        self.__modsloaded[modname] = moduleimp
-
-
     def ModulesLoaded(self):
         "Returns number of registered module objects"
         return len(self.__modobjects)
 
 
-    def GetModulesList(self):
-        "Returns a list of module names"
-        return list(self.__modobjects.keys())
-
-
-    def GetNamedModuleObject(self, modname):
-        "Looks up a named module and returns its registered module object"
-        return self.__modobjects[modname]
-
-
     def __iter__(self):
         "Initiates the iterating process"
 
@@ -414,10 +405,6 @@ class RtEvalModules:
     # Export some of the internal module container methods
     # Primarily to have better control of the module containers
     # iteration API
-    def _ImportModule(self, module):
-        "Imports a module exported by ModuleContainer::ExportModule()"
-        return self.__modules.ImportModule(module)
-
     def _InstantiateModule(self, modname, modcfg, modroot=None):
         "Imports a module and returns an instantiated object from the module"
         return self.__modules.InstantiateModule(modname, modcfg, modroot)
@@ -434,17 +421,9 @@ class RtEvalModules:
         "Returns number of imported modules"
         return self.__modules.ModulesLoaded()
 
-    def GetModulesList(self):
-        "Returns a list of module names"
-        return self.__modules.GetModulesList()
-
     def SetupModuleOptions(self, parser):
         "Sets up argparse based argument groups for the loaded modules"
         return self.__modules.SetupModuleOptions(parser, self._cfg)
-
-    def GetNamedModuleObject(self, modname):
-        "Returns a list of module names"
-        return self.__modules.GetNamedModuleObject(modname)
     # End of exports
 
 
@@ -457,9 +436,14 @@ class RtEvalModules:
 
         self._logger.log(Log.INFO, f"Preparing {self._module_type} modules")
         exclusive = 0
+        latency_test = False
         for (modname, mod) in self.__modules:
             if mod.is_exclusive() and mod.WorkloadWillRun():
                 exclusive += 1
+            if mod._latency_test:
+                if latency_test:
+                    raise RuntimeError("More than one exclusive latency test")
+                latency_test = True
         for (modname, mod) in self.__modules:
             if exclusive >= 1:
                 if exclusive != 1:
@@ -495,9 +479,8 @@ class RtEvalModules:
 
 
     def Unleash(self):
-        """Unleashes all the loaded modules workloads"""
+        """Unleashes all the loaded modules"""
 
-        # turn loose the loads
         nthreads = 0
         self._logger.log(Log.INFO, f"Sending start event to all {self._module_type} modules")
         for (modname, mod) in self.__modules:
@@ -508,7 +491,7 @@ class RtEvalModules:
         return nthreads
 
 
-    def _isAlive(self):
+    def isAlive(self):
         """Returns True if all modules are running"""
 
         for (modname, mod) in self.__modules:
@@ -555,6 +538,8 @@ class RtEvalModules:
         rep_n = libxml2.newNode(self._report_tag)
 
         for (modname, mod) in self.__modules:
+            if mod.hadRuntimeError():
+                continue
             self._logger.log(Log.DEBUG, f"Getting report from {modname}")
             modrep_n = mod.MakeReport()
             if modrep_n is not None:
